
# Slot: reference

The publication of reference that describes the evidence

URI: [gocam:evidenceItem__reference](https://w3id.org/gocam/evidenceItem__reference)


## Domain and Range

None &#8594;  <sub>0..1</sub> [PublicationObject](PublicationObject.md)

## Parents


## Children


## Used by

 * [EvidenceItem](EvidenceItem.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example({'value': 'PMID:32075755'}) |
